# Control panels for Plone 5 have been moved to CMFPlone. We keep those imports
# for backwards compatibility.
from Products.CMFPlone.interfaces import ISiteSchema  # noqa
from Products.CMFPlone.controlpanel.site import SiteControlPanel  # noqa
from Products.CMFPlone.controlpanel.bbb.site import SiteControlPanelAdapter  # noqa



# Control panels for Plone 5 have been moved to CMFPlone. We keep those imports
# for backwards compatibility.
from Products.CMFPlone.interfaces import ILanguageSelectionSchema  # noqa
from Products.CMFPlone.controlpanel.language import LanguageControlPanel  # noqa
from Products.CMFPlone.controlpanel.bbb.language import LanguageControlPanelAdapter  # noqa



# Control panels for Plone 5 have been moved to CMFPlone. We keep those imports
# for backwards compatibility.
from Products.CMFPlone.interfaces import INavigationSchema  # noqa
from Products.CMFPlone.controlpanel.navigation import NavigationControlPanel  # noqa
from Products.CMFPlone.controlpanel.bbb.navigation import NavigationControlPanelAdapter  # noqa



# Control panels for Plone 5 have been moved to CMFPlone. We keep those imports
# for backwards compatibility.
from Products.CMFPlone.interfaces import ISearchSchema  # noqa
from Products.CMFPlone.controlpanel.search import SearchControlPanel  # noqa
from Products.CMFPlone.controlpanel.bbb.search import SearchControlPanelAdapter  # noqa



# Control panels for Plone 5 have been moved to CMFPlone. We keep those imports
# for backwards compatibility.
from Products.CMFPlone.interfaces import IFilterTagsSchema  # noqa
from Products.CMFPlone.interfaces import IFilterAttributesSchema  # noqa
from Products.CMFPlone.interfaces import IFilterEditorSchema  # noqa
from Products.CMFPlone.controlpanel.filter import FilterControlPanel  # noqa
from Products.CMFPlone.controlpanel.bbb.filter import FilterControlPanelAdapter  # noqa



# Control panels for Plone 5 have been moved to CMFPlone. We keep those imports
# for backwards compatibility.
from Products.CMFPlone.interfaces import IMailSchema  # noqa
from Products.CMFPlone.controlpanel.markup import MarkupControlPanel  # noqa
from Products.CMFPlone.controlpanel.bbb.markup import MarkupControlPanelAdapter  # noqa



# Control panels for Plone 5 have been moved to CMFPlone. We keep those imports
# for backwards compatibility.
from Products.CMFPlone.interfaces import ISecuritySchema  # noqa
from Products.CMFPlone.controlpanel.browser.security import SecurityControlPanel  # noqa
from Products.CMFPlone.controlpanel.bbb.security import SecurityControlPanelAdapter  # noqa



# -*- coding: utf-8 -*-
from Products.CMFPlone.interfaces import controlpanel


class IPloneControlPanelView(controlpanel.IPloneControlPanelView):
    """BBB class
    DONT USE UNLESS YOU RUN INTO BACKWARD COMPATIBILITY PROBLEMS
    """


class IPloneControlPanelForm(controlpanel.IPloneControlPanelForm):
    """BBB class
    DONT USE UNLESS YOU RUN INTO BACKWARD COMPATIBILITY PROBLEMS
    """


class IConfigurationChangedEvent(controlpanel.IConfigurationChangedEvent):
    """BBB class
    DONT USE UNLESS YOU RUN INTO BACKWARD COMPATIBILITY PROBLEMS
    """



# Control panels for Plone 5 have been moved to CMFPlone. We keep those imports
# for backwards compatibility.
from Products.CMFPlone.interfaces import IEditingSchema  # noqa
from Products.CMFPlone.controlpanel.editing import EditingControlPanel  # noqa
from Products.CMFPlone.controlpanel.bbb.editing import EditingControlPanelAdapter  # noqa



from setuptools import setup, find_packages

version = '4.0.1'

setup(name='plone.app.controlpanel',
      version=version,
      description="Controlpanels for Plone were moved to Products.CMFPlone.",
      long_description=open("README.rst").read() + "\n" +
                       open("CHANGES.rst").read(),
      classifiers=[
          "Development Status :: 6 - Mature",
          "Environment :: Web Environment",
          "Framework :: Plone",
          "Framework :: Zope2",
          "Framework :: Zope :: 4",
          "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
          "Operating System :: OS Independent",
          "Programming Language :: Python",
          "Programming Language :: Python :: 2.7",
        ],
      keywords='plone controlpanel bbb',
      author='Plone Foundation',
      author_email='plone-developers@lists.sourceforge.net',
      url='https://pypi.org/project/plone.app.controlpanel',
      license='GPL version 2',
      packages=find_packages(),
      namespace_packages=['plone', 'plone.app'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
        'setuptools',
        'Products.CMFPlone>=5.1.9999',
      ],
      extras_require={
        'test': [
        ]
      }
      )



# Control panels for Plone 5 have been moved to CMFPlone. We keep those imports
# for backwards compatibility.
from Products.CMFPlone.interfaces import IMailSchema  # noqa
from Products.CMFPlone.controlpanel.mail import MailControlPanel  # noqa
from Products.CMFPlone.controlpanel.bbb.mail import MailControlPanelAdapter  # noqa



# Control panels for Plone 5 have been moved to CMFPlone. We keep those imports
# for backwards compatibility.
from Products.CMFPlone.interfaces import IConfigurationChangedEvent  # noqa
from Products.CMFPlone.controlpanel.events import ConfigurationChangedEvent  # noqa
from Products.CMFPlone.controlpanel.events import handleConfigurationChangedEvent  # noqa
